@@ -1,28 +1,31 @@
 #' @export
 #' @rdname storms
-storm_shp <- function(basin=NULL, storm=NULL, year=NULL, type="points", path="~/.rnoaa/storms",
-  overwrite = TRUE)
-{
+storm_shp <- function(basin=NULL, storm=NULL, year=NULL, type="points", 
+                      path="~/.rnoaa/storms", overwrite = TRUE) {
+  
   shppath <- shp_local(basin, storm, year, path, type)
-  if(!is_shpstorm(x = shppath)){
+  if (!is_shpstorm(x = shppath)) {
     shppath <- shpstorm_GET(path, basin, storm, year, type, overwrite)
   }
-  structure(list(path=spth(shppath)), class="storm_shp", 
-            basin=basin, storm=storm, year=year, type=type)
+  structure(list(path = spth(shppath)), class = "storm_shp", 
+            basin = basin, storm = storm, year = year, type = type)
 }
 
 #' @export
 #' @rdname storms
-storm_shp_read <- function(x){
+storm_shp_read <- function(x) {
   readshp2(x$path, filepath2(attr(x, 'basin'), attr(x, 'storm'), attr(x, 'year'), attr(x, 'type')))
 }
 
-an <- function(x, y){ tmp <- attr(x, y); if(is.null(tmp)) '<NA>' else tmp }
+an <- function(x, y) { 
+  tmp <- attr(x, y)
+  if (is.null(tmp)) '<NA>' else tmp 
+}
 
-spth <- function(x)  grep("\\.shp", x, value = TRUE)
+spth <- function(x) grep("\\.shp", x, value = TRUE)
 
 #' @export
-print.storm_shp <- function(x, ...){
+print.storm_shp <- function(x, ...) {
   cat("<NOAA Storm Shp Files>", sep = "\n")
   cat(sprintf("Path: %s", x$path), sep = "\n")
   cat(sprintf("Basin: %s", an(x, "basin")), sep = "\n")
@@ -31,22 +34,23 @@ print.storm_shp <- function(x, ...){
   cat(sprintf("Type: %s", an(x, "type")), sep = "\n")
 }
 
-shpstorm_GET <- function(bp, basin, storm, year, type, overwrite){
+shpstorm_GET <- function(bp, basin, storm, year, type, overwrite) {
   dir.create(local_base(basin, storm, year, bp), showWarnings = FALSE, recursive = TRUE)
   fp <- shp_local(basin, storm, year, bp, type)
   paths <- Map(function(x, y) suppressWarnings(GET(x, write_disk(y, overwrite))), shp_remote(basin, storm, year, type), fp)  
-  vapply(paths, function(z) z$request$writer[[1]], "", USE.NAMES = FALSE)
+  vapply(paths, function(z) z$request$output$path, "", USE.NAMES = FALSE)
 }
 
-shpfileext <- function(basin, storm, year, type){
+shpfileext <- function(basin, storm, year, type) {
   tt <- filepath(basin, storm, year)
-  if(grepl("Allstorms", tt)) 
+  if (grepl("Allstorms", tt)) {
     paste0(tt, '.ibtracs_all_', type, '.v03r06.', c('dbf','prj','shp','shx'), '.gz')
-  else 
+  } else {
     paste0(tt, '.ibtracs_all_', type, '.v03r06.', c('dbf','prj','shp','shx'))
+  }
 }
 
-filepath2 <- function(basin, storm, year, type){
+filepath2 <- function(basin, storm, year, type) {
   tmp <- filecheck(basin, storm, year)
   switch(names(tmp),
          all = 'Allstorms',
@@ -58,5 +62,5 @@ filepath2 <- function(basin, storm, year, type){
 
 shp_remote <- function(basin, storm, year, type) file.path(stormurl("shp"), shpfileext(basin, storm, year, type))
 shp_local <- function(basin, storm, year, path, type) file.path(path, shpfileext(basin, storm, year, type))
-is_shpstorm <- function(x) if(all(file.exists(x))) TRUE else FALSE
-readshp2 <- function(x, layer) readOGR(dsn = path.expand(x), layer = layer, stringsAsFactors = FALSE)
+is_shpstorm <- function(x) if (all(file.exists(x))) TRUE else FALSE
+readshp2 <- function(x, layer) readOGR(dsn = path.expand(x), layer = layer, stringsAsFactors = FALSE, verbose = FALSE)
